@@ -57,6 +57,7 @@ import pandas as pd
 
 from metacatalog.models import Entry, EntryGroup
 from metacatalog.util.exceptions import MetadataMissingError
+from metacatalog.util.dict_functions import flatten
 
 
 class ImmutableResultSet:
@@ -276,6 +277,9 @@ class ImmutableResultSet:
         # expand to all members
         checksums.extend([e.checksum for e in self._members])
 
+        # checksums need to be sorted
+        checksums = sorted(checksums)
+
         return checksums
 
     @property
@@ -382,9 +386,9 @@ class ImmutableResultSet:
                     data[member.checksum] = df
                 elif len(unmerged) > 0:
                     data[member.checksum] = unmerged
-        
-        # Composites always try to merge
-        if self.group is not None and self.group.type.name == 'Composite':
+
+        # Composites and Split datasets always try to merge
+        if self.group is not None and self.group.type.name in ('Composite', 'Split dataset'):
             merge = True
 
         # handle merging
@@ -393,12 +397,27 @@ class ImmutableResultSet:
             all_data = pd.DataFrame()
             unmerged = {}
             
-            # merge everything that is a DataFrame
-            for checksum, dat in data.items():
-                if isinstance(dat, pd.DataFrame):
-                    all_data = pd.merge(all_data, dat, left_index=True, right_index=True, how='outer')
-                else:
-                    unmerged.update({checksum: dat})
+            # Composite: merge everything that is a DataFrame
+            if self.group is not None and self.group.type.name == 'Composite':
+                for checksum, dat in data.items():
+                    if isinstance(dat, pd.DataFrame):
+                        all_data = pd.merge(all_data, dat, left_index=True, right_index=True, how='outer')
+                    else:
+                        unmerged.update({checksum: dat})
+            # Split dataset: concat everything that is a DataFrame
+            elif self.group is not None and self.group.type.name == 'Split dataset':
+                for checksum, dat in data.items():
+                    if isinstance(dat, pd.DataFrame):
+                        all_data = pd.concat([all_data, dat])
+                    else:
+                        unmerged.update({checksum: dat})
+            # other EntryGroup types?
+            else:
+                for checksum, dat in data.items():
+                    if isinstance(dat, pd.DataFrame):
+                        all_data = pd.merge(all_data, dat, left_index=True, right_index=True, how='outer')
+                    else:
+                        unmerged.update({checksum: dat})
             
             # specify return type
             if len(unmerged.keys()) == 0 and not all_data.empty:
@@ -413,4 +432,207 @@ class ImmutableResultSet:
             out = data
         
         # return
-        return out
\ No newline at end of file
+        return out
+
+
+class ResultList:
+    """
+    Container class to handle multiple instances of 
+    :class:`ImmutableResultSet <metacatalog.util.results.ImmutableResultSet>`.
+
+    """
+    def __init__(self, *members: List[Union[ImmutableResultSet, Entry, EntryGroup]]):
+        """
+        """
+        # set up the internal list
+        self._internal_list = []
+        
+        # check types
+        if not all([isinstance(m, (ImmutableResultSet, Entry, EntryGroup)) for m in members]):
+            raise AttributeError('Unallowed type found in members')
+
+        # lazy load anything that is not already a ImmutableResultSet
+        results = [ImmutableResultSet(m) if not isinstance(m, ImmutableResultSet) else m for m in members]
+
+        # set the filtered list
+        self._internal_list = self._filter_set(results)
+
+    @property
+    def checksums(self):
+        return [m.checksum for m in self._internal_list]
+    
+    def _filter_set(self, members: List[ImmutableResultSet]) -> List[ImmutableResultSet]:
+        """
+        Uses the checksum of each member to create a set od ImmutableResultSet
+        """
+        # extract the checksums
+        md5s = [m.checksum for m in members]
+
+        # find the first occurence of each
+        filtered = [members[i] for i, md5 in enumerate(md5s) if md5s.index(md5) == i]
+
+        return filtered
+
+    def append(self, item: Union[Entry, EntryGroup, ImmutableResultSet]):
+        """
+        Append a new ImmutableResultSet to the ResultList. Note that the
+        list does not allow duplicates and will raise a Warning if the 
+        item is already contained.
+        You can also pass :class:`Entry <metacatalog.models.Entry>` and
+        :class:`EntryGroup <metacatalog.models.EntryGroup>` instances,
+        which will be converted to ImmutableResultSets.
+
+        """
+        # convert if needed
+        if isinstance(item, (Entry, EntryGroup)):
+            item = ImmutableResultSet(item)
+
+        # check if exists
+        if item.checksum in self:
+            print('This ResultList already includes the item')
+        else:
+            self._internal_list.append(item)
+
+    def index(self, item: Union[ImmutableResultSet, Entry, EntryGroup, str]) -> int:
+        """
+        Get the index of a member in this list.
+        The function accepts many different types, which will be converted to 
+        a ImmutableResultSet. If a string is passed, it will first be interpreted
+        as a MD5 checksum of the ImmutableResultSet. If no occurence of that string
+        is found, *every* member is **recursively** searched for a key of that
+        string in the metadata. The first occurence is passed.
+
+        .. note::
+            This method is quite slow, due to the type casting, lazy-loading from
+            database and the recursive behavior. If you want to search by MD5 hash
+            you can directly use the ResultSet.checksums property, which preserves
+            the member order.
+        
+        Raises
+        ------
+        ValueError : if item is not present
+        AttributeError : if unsupported item is passed
+
+        """
+        # cast the item if needed
+        if isinstance(item, (Entry, EntryGroup)):
+            item = ImmutableResultSet(item)
+        
+        # handle ResultSet
+        if isinstance(item, ImmutableResultSet):
+            # check if we have this item
+            if item in self:
+                return self.checksums.index(item.checksum)
+
+        # handle strings
+        elif isinstance(item, str):
+            # check if the item is a checksum
+            if item in self.checksums:
+                return self.checksums.index(item)
+            
+            # otherwise check every member recursively
+            for i, member in enumerate(self._internal_list):
+                flatdict = flatten(member.to_dict())
+                
+                # this is a hit
+                if item in list(flatdict.values()):
+                    return i
+
+        # else the item is unsupported
+        else:
+            raise AttributeError('The item type is not supported')
+        
+        # if still not returned, raise the Value Error
+        raise ValueError('The item is not in the current ResultList')
+
+    @property
+    def temporal_scale(self):
+        """
+        Common temporal scale triplet for the whole ResultList.
+        Only information of :class:`Entries <metacatalog.models.Entry>`
+        that hold time scale information are included.
+        The common scale triplet is calculated:
+        The extent is the maximum period, where **all** members in 
+        the list have data. If extent is ``None``, no overlap was
+        found. 
+        The resolution is the maximum (most coarse) resolution
+        in the List, which needs to be aggregated to, if the data
+        should be harmonized.
+        The support is recalulated by converting the minimum
+        support and re-scaling it to the new resolution.  
+
+        Returns
+        -------
+        triplet : dict
+            Dict of extent, resolution and support key.
+
+        See Also
+        --------
+        TemporalScale : metacatalog.models.TemporalScale
+
+        """
+        # first collect the scaling information
+        scales = dict(start=[], end=[], resolution=[], support=[])
+        
+        # read out each resultset
+        for result in self._internal_list:
+            ds = result.get('datasource')
+
+            # check if exists
+            if ds is None:
+                continue
+            
+            sca = []
+            # flat reuslts
+            if 'temporal_scale' in ds.keys():
+                sca.append(ds['temporal_scale'])
+            # more than one datasource in result set
+            else:
+                for s in list(ds.values()):
+                    if isinstance(s, dict) and 'temporal_scale' in s:
+                        sca.append(s['temporal_scale'])
+            
+            # go for each scale triplet found
+            for s in sca:
+                scales['start'].append(s['extent'][0])
+                scales['end'].append(s['extent'][1])
+                scales['resolution'].append(pd.to_timedelta(s['resolution']).to_pytimedelta())
+                scales['support'].append(float(s['support']))
+        
+        # finally find the smallest
+        start = min(scales['start'])
+        end = max(scales['end'])
+        resolution = max(scales['resolution'])
+        # get the smallest support in seconds
+        support = min([r.seconds * s for r, s in zip(scales['resolution'], scales['support'])])
+        support = support / resolution.seconds
+
+        return dict(
+            extent=[start, end] if start < end else [],
+            resolution=pd.to_timedelta(resolution).isoformat(),
+            support=support
+        )
+
+    def __call__(self) -> List[ImmutableResultSet]:
+        return self._internal_list
+
+    def __iter__(self):
+        yield from self._internal_list
+
+    def __len__(self):
+        return len(self._internal_list)
+
+    def __contains__(self, item: ImmutableResultSet) -> bool:
+        return item.checksum in [m.checksum for m in self._internal_list]
+
+    def __getitem__(self, key: Union[int, slice]):
+        return self._internal_list[key]
+    
+    def __setitem__(self, key, value):
+        raise NotImplementedError("You can't directly set items. Use the append method")
+    
+    def __str__(self) -> str:
+        return self._internal_list.__str__()
+    
+    def __repr__(self) -> str:
+        return self._internal_list.__repr__()
